{% extends "department.html" %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}
{% load unicms_template_unical %}

<!-- Logo in Header -->
{% block header_center_logo_side %}
<image src="{% unicms_template_unical_static_path 'images/logos/demacs.svg' %}" class="h-100" />
{% endblock header_center_logo_side %}

{% block header_slim_mobile_org_name_side %}
<image src="{% unicms_template_unical_static_path 'images/logos/demacs.svg' %}" class="mw-100" />
{% endblock header_slim_mobile_org_name_side %}

{% block department_contacts %}
<div class="col-12 col-lg-3">
    <div class="mb-3">
        <image src="{% unicms_template_unical_static_path 'images/logos/demacs.svg' %}"
               class="w-100 h-100"
               alt="{% trans 'Department of Mathematics and Computer Science' %}"/>
    </div>
    <p class="mb-4">
        Via P. Bucci - Edificio 30B
        <br>
        87036 Arcavacata di Rende (CS)
        <br>
        <a class="text-white" href="mailto:dipartimento.demacs@unical.it" title="dipartimento.demacs@unical.it">dipartimento.demacs@unical.it</a>
        <br>
        <a class="text-white" href="mailto:dipartimento.demacs@pec.unical.it" title="dipartimento.demacs@pec.unical.it">dipartimento.demacs@pec.unical.it</a>
        <br>
        +39 0984 496409
    </p>
</div>
{% endblock department_contacts %}

{% block footer_top %}
<div class="container text-center text-lg-start">
    <ul class="list-inline social py-4 mt-2 mb-0">
        <li class="list-inline-item">
            <a class="p-2" href="https://www.facebook.com/Dipartimento-di-Matematica-e-Informatica-Universit%C3%A0-Della-Calabria-Unical-173838039327576/" target="_blank" rel="noopener noreferrer" title="Facebook">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-facebook-square"></use>
                </svg><span class="visually-hidden">Facebook</span>
            </a>
        </li>
        <li class="list-inline-item">
            <a class="p-2" href="https://www.instagram.com/demacs_official/?hl=it" target="_blank" rel="noopener noreferrer" title="Instagram">
                <svg class="icon icon-secondary align-top">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-instagram"></use>
                </svg><span class="visually-hidden">Instagram</span>
            </a>
        </li>
    </ul>
</div>
{% endblock footer_top %}
