{% extends "blocks/unical_page_publication_preview_1.html" %}

{% block title %}
<h4>{{ publication.title }}</h4>
{% endblock title %}

{% block publication_content %}
{{ publication.content|safe }}
{% endblock publication_content %}
