{% extends "bases/unicms_unical.html" %}


{% block section_1 %}

{% endblock %}

{% block section_2 %}
    {% with section_2_template="grid/section_2/section_center_alternative.html" %}
    {{ block.super }}
    {% endwith %}
{% endblock %}
