{% extends 'bases/unicms_unical.html' %}

{% load i18n %}
{% load static %}

{% block header_slim_right_zone %}{% endblock header_slim_right_zone %}
{% block header_center_right_zone %}{% endblock header_center_right_zone %}

{% block head_inits %}{% endblock head_inits %}

{% block main_menu %}{% endblock main_menu %}

{% block container %}
<div class="container">
    <div class="col-12 bd-content">
        {% block centered_container %}
        <div class="callout danger my-5">
            <div class="callout-title">
                <svg class="icon icon-primary icon-danger">
                    <use xlink:href="{% static 'svg/sprites.svg' %}#it-close-circle"></use>
                </svg>
                {% block error_type %}
                    {% trans "Error" %}
                {% endblock error_type %}
            </div>
            <p>
                {% block error_description %}
                    {% trans "Error description" %}
                {% endblock error_description %}
                <hr>
                <a role="button" class="btn btn-primary d-block d-lg-inline" href="/">
                    {% trans "Home" %}
                </a>
                {% block other_buttons %}
                {% endblock other_buttons %}
            </p>
        </div>
        {% endblock centered_container %}
    </div>
</div>
{% endblock container %}
