{% load i18n %}
{% load static %}

{% load unicms_contexts %}


<div class="container">
    <div class="row py-4">
        {% for item in items %}
            {% call obj=item method='link' request=request as link %}
            <div class="col-12 col-lg-auto">
                <div class="text-center d-inline-block me-4">
                    <a href="{{ link }}" class="no-color">
                        <span class="text-black fw-bold">
                            <svg class="icon me-2">
                                <use xlink:href="{% static '/svg/sprites.svg' %}#it-arrow-right-circle"></use>
                            </svg>
                            {{ item.name }}
                        </span>
                    </a>
                </div>
            </div>
        {% endfor %}
    </div>
</div>
