/**
 * Università della Calabria COLORS
 */

:root {
  --bordeaux_unical: #396;
  --dark_grey_unical: #383838;
  --light_grey_unical: #9d9d9c;
  --white: #ffffff;

  --cyan: #176fc1;
  --grey: #d3d2cf;
  --light_grey: #e3e9ec;

  --darker_bordeaux: #6f0b0a;
  --lighter_bordeaux: #e03231;

  --exbriner_red: #f00;
}

a {
    color: var(--bordeaux_unical);
}

a:hover, a:active {
    color: var(--dark_grey_unical);
}
a.read-more{
    color: var(--light_grey_unical);
}
.badge-primary {
    background: var(--bordeaux_unical);
}
.badge-secondary {
    background: var(--dark_grey_unical);
}
.btn-primary {
    background: var(--dark_grey_unical);
}
.btn-primary:hover {
    background: var(--light_grey_unical);
}

.btn-outline-primary,
.btn-outline-primary:visited {
    color: var(--dark_grey_unical);
    -webkit-box-shadow: inset 0 0 0 1px var(--dark_grey_unical);
    box-shadow: inset 0 0 0 1px var(--dark_grey_unical);
}
.btn-outline-primary:hover {
    color: var(--light_grey_unical);
    -webkit-box-shadow: inset 0 0 0 1px var(--light_grey_unical);
    box-shadow: inset 0 0 0 1px var(--light_grey_unical);
}
.btn-outline-primary:active,
.btn-outline-primary:focus {
    color: var(--dark_grey_unical) !important;
    box-shadow: inset 0 1px 0 var(--light_grey_unical), 0 1px 1px var(--light_grey_unical), 0 0 0 0.2rem rgba(101, 101, 102, 0.5) !important;
}
.btn-secondary {
    background: var(--bordeaux_unical);
}
.btn-secondary:hover {
    background: var(--dark_grey_unical);
}
.btn:not(.btn-outline-primary):not(.btn-outline-secondary):active,
.btn:not(.btn-outline-primary):not(.btn-outline-secondary):focus {
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 0 0.2rem rgba(101, 101, 102, 0.5) !important;
    background-color:#475664 !important;
}
.text-primary {
    color: var(--dark_grey_unical) !important;
}
.text-secondary {
    color: var(--bordeaux_unical) !important;
}

/**
 * Header Slim Wrapper
 */
.it-header-slim-wrapper{
    background: var(--bordeaux_unical);
 }
.it-header-slim-wrapper .it-header-slim-wrapper-content .header-slim-right-zone button{
    background: var(--dark_grey_unical);
}
.it-header-slim-wrapper .it-header-slim-wrapper-content .header-slim-right-zone button:hover{
    background: var(--light_grey_unical);
    color: var(--dark_grey_unical);
}

.it-header-center-wrapper .it-header-center-content-wrapper .it-brand-wrapper a,
.it-header-center-wrapper .it-header-center-content-wrapper .it-right-zone{
    color: var(--dark_grey_unical);
}
.it-header-center-wrapper .it-header-center-content-wrapper .it-right-zone .it-socials ul .icon,
.it-header-center-wrapper .it-header-center-content-wrapper .it-search-wrapper a.rounded-icon svg{
    fill: var(--dark_grey_unical);
}

/**
 * Header Navbar Wrapper
 */

/* Desktops and laptops ----------- */
@media (min-width : 992px) {
    .it-header-navbar-wrapper {
        background: var(--dark_grey_unical);
    }
}
/* Others than desktop ----------- */
@media (max-width : 991px) {
    .it-header-navbar-wrapper {
        background: none;
    }
    .custom-navbar-toggler svg{
        fill: var(--dark_grey_unical);
    }
}

/**
 * Footer Main
 */
.it-footer-main{
    background: var(--bordeaux_unical);
}

/**
 * Footer Small Prints
 */
.it-footer-small-prints{
    background: var(--bordeaux_unical);
}

/**
 * Carousel
 */
.it-carousel-wrapper .owl-dots .owl-dot{
    background: var(--dark_grey_unical);
}

/**
 * Back to top
 */
.back-to-top {
    background: var(--white);
}
.back-to-top:hover {
    background: var(--dark_grey_unical);
}

/**
 * Form Bootstrap Italia
 */
 .toggles label input[type="checkbox"]:checked + .lever::after {
    background-color: var(--bordeaux_unical);
}
.form-check [type=radio]:checked+label::after,
.form-check [type=checkbox]:checked+label::after {
    background-color: var(--bordeaux_unical);
    border-color: var(--bordeaux_unical);
}
.form-check [type=radio]:checked+label::before {
    border-color: var(--bordeaux_unical);
}

/** only visited **/
a.no-color,
ol.breadcrumb a  {
    color: var(--dark_grey_unical);
}

.background-white {
    background: var(--white);
}

.background-light-grey {
    background: var(--light_grey);
    color: var(--dark_grey_unical);
}

.icon-light {
    fill: var(--bordeaux_unical) !important;
}

.dark-grey-background {
    background: var(--grey);
}

.it-header-center-wrapper {
    background: var(--white);
}

.it-header-center-wrapper .it-header-center-content-wrapper .it-right-zone {
    color: #fff;
}

input.top-input {
    background: none;
    border: 1px solid var(--bordeaux_unical);
}

.it-hero-wrapper .it-hero-text-wrapper h1 {
    background: #fff;
    color: #0000ff;
}

.it-hero-wrapper.it-overlay.it-dark .img-responsive-wrapper:after {
    background: none;
}

.section-title-label {
    background: #fff;
}

.card .etichetta {
    color: var(--cyan);
}

.btn-grey-presta {
    background: var(--grey);
}
.btn-grey-presta:hover {
    color: var(--white);
    background: var(--dark_grey_unical);
}
.bg-dark .btn-secondary {
    background: var(--bordeaux_unical);
}
.bg-dark .btn-secondary:hover {
    background: var(--dark_grey_unical);
}

.it-right-zone .nav-link {
    color: var(--white);
}

@media (max-width: 991px) {
    .custom-navbar-toggler svg {
        fill: var(--white);
    }
}

.it-header-slim-wrapper {
    background: #00f;
    border-bottom: 1px solid #fff;
}

.badge-grey-unical {
    background: var(--light_grey);
    color: var(--dark_grey_unical);
}

a .badge-grey-unical:hover,
a .badge-grey-unical.selected {
    background: var(--dark_grey_unical);
    color: var(--light_grey);
}

.breadcrumb-container {
    border-top: 2px solid var(--bordeaux_unical);
    border-bottom: 2px solid var(--bordeaux_unical);
}

@media (min-width: 992px) {
    .it-header-navbar-wrapper {
        background: var(--white);
    }
}

.it-hero-wrapper {
    background-color: #fff !important;
}

.bordeaux-unical-bg {
    background: var(--bordeaux_unical);
}

.bordeaux-unical-color {
    color: var(--bordeaux_unical);
}

.white-unical-color {
    color: var(--white);
}

.accordion-header [data-bs-toggle=collapse][aria-expanded=false],
.accordion-header [data-bs-toggle=collapse]:before {
    color: var(--dark_grey_unical);
}

.accordion-header{
    border-color: #e3e4e6 !important;
}

.nav-tabs .nav-link,
.nav-tabs .nav-link:hover {
    color: var(--light_grey_unical);
}
.nav-tabs .nav-item.show .nav-link, .nav-tabs .nav-link.active {
    border-bottom-color: var(--bordeaux_unical);
    color: var(--dark_grey_unical);
}

.link-list-wrapper ul li a span,
.link-list-wrapper ul li a:hover:not(.disabled) span {
    color: var(--dark_grey_unical);
}

.card .card-body a h5.card-title {
    color: var(--dark_grey_unical);
}

.progress-spinner.progress-spinner-double .progress-spinner-inner:after {
    border: 4px solid var(--bordeaux_unical);
    border-right: 4px solid transparent;
    border-bottom: 4px solid transparent;
}

figure.table tr:nth-of-type(2n) {
    background-color: #f6f7f9;
}

.progress {
    background-color: var(--light_grey);
}
.progress-bar {
    background-color: var(--bordeaux_unical);
}

.it-footer-small-prints {
    border-top: 1px solid #fff;
}

.it-hero-wrapper .it-hero-text-wrapper h5.unical-hero-preheading {
    background: var(--bordeaux_unical);
    color: #fff;
}

.it-hero-wrapper .it-hero-text-wrapper h6.unical-hero-preheading {
    background: var(--bordeaux_unical);
    color: #fff;
}

.it-hero-wrapper .it-hero-text-wrapper h1.unical-hero-heading,
.it-hero-wrapper .it-hero-text-wrapper h2.unical-hero-heading,
.it-hero-wrapper .it-hero-text-wrapper h3.unical-hero-heading,
.it-hero-wrapper .it-hero-text-wrapper h4.unical-hero-heading {
    background: #fff;
    color: var(--bordeaux_unical);
}

.it-footer-main h4 a {
    border-bottom: 1px solid var(--bordeaux_unical);
}

input.top-input::placeholder {
    color: var(--bordeaux_unical);
}

/**
 * custom
 */
.it-header-wrapper .it-nav-wrapper .it-header-navbar-wrapper {
    background: var(--bordeaux_unical);
}

@media (min-width: 992px){
    .menu-wrapper li.megamenu a.nav-link {
        color: var(--white) !important;
    }
}
