{% extends "department.html" %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}
{% load unicms_template_unical %}


{% block header_center_url %}
/didattica/offerta-formativa/master-e-alta-formazione/master/manager-di-impianti-ed-eventi-sportivi-complessi/
{% endblock header_center_url %}

{% block header_mobile_center_url %}
/didattica/offerta-formativa/master-e-alta-formazione/master/manager-di-impianti-ed-eventi-sportivi-complessi/
{% endblock header_mobile_center_url %}

<!-- Logo in Header -->
{% block header_center_logo_side %}
<image src="{% unicms_template_unical_static_path 'images/logos/master_ges.png' %}" class="h-100" />
{% endblock header_center_logo_side %}

{% block header_slim_mobile_org_name_side %}
<image src="{% unicms_template_unical_static_path 'images/logos/master_ges.png' %}" class="mw-100" />
{% endblock header_slim_mobile_org_name_side %}

{% block header_center_right_zone %}
{% endblock header_center_right_zone %}

{% block unical_header_languages %}
{% endblock unical_header_languages %}

{% block footer_top %}
{% endblock footer_top %}

{% block footer_bottom_1 %}
<div class="col-lg-4 col-sm-6">
    <div class="link-list-wrapper">
        <ul class="footer-list link-list clearfix">
            <li><a class="list-item" href="/" title="{% trans 'Portale UniCal' %}">{% trans 'Portale UniCal' %}</a></li>
            <li><a class="list-item" href="https://dimeg.unical.it" title="{% trans 'Portale DIMEG' %}">{% trans 'Portale DIMEG' %}</a></li>
            <li><a class="list-item" href="/didattica/offerta-formativa/master-e-alta-formazione/" title="{% trans 'Master e Alta Formazione' %}">{% trans 'Master e Alta Formazione' %}</a></li>
        </ul>
    </div>
</div>
{% endblock footer_bottom_1 %}

{% block footer_bottom_2 %}
<div class="col-lg-4 col-sm-6">
    <div class="link-list-wrapper">
        <ul class="footer-list link-list clearfix">
            <li><a class="list-item" href="/privacy/" title="{% trans 'Data protection / GDPR' %}">{% trans 'Data protection / GDPR' %}</a></li>
            <li><a class="list-item" href="/cookie/" title="{% trans 'Cookies and consent methods' %}">{% trans 'Cookies and consent methods' %}</a></li>
            <li><a class="list-item" href="/accessibilita/" title="{% trans 'Accessibility and performance' %}">{% trans 'Accessibility and performance' %}</a></li>
        </ul>
    </div>
</div>
{% endblock footer_bottom_2 %}

{% block footer_bottom_3 %}
<div class="col-lg-4 col-sm-6">
    <div class="link-list-wrapper">
        <ul class="footer-list link-list clearfix">
            <li><a class="list-item" href="/note-legali/" title="{% trans 'Legal notes' %}">{% trans 'Legal notes' %}</a></li>
            <li><a class="list-item" href="/credits/" title="{% trans 'Credits' %}">{% trans 'Credits' %}</a></li>
        </ul>
    </div>
</div>
{% endblock footer_bottom_3 %}

{% block department_contacts %}
<div class="col-12 col-lg-3">
    <div class="mb-3">
        <image src="{% unicms_template_unical_static_path 'images/logos/master_ges.png' %}"
               class="w-100 h-100"
               alt="{% trans 'Manager di impianti ed eventi sportivi complessi' %}"/>
    </div>
    <p class="mb-4">
        Via P. Bucci - Cubo 46C, ponte carrabile
        <br>
        87036 Arcavacata di Rende (CS)
    </p>
</div>
{% endblock department_contacts %}
